### This is a package with interview task.

[flashlight.py](flashlight/flashlight.py) - solving the problem of implementing a network flashlight.

[tests.py](flashlight/tests.py) - unittests for flashlight.py

### Installation:
> pip install flashlight-pavel-ivanov928==1.0
